@@ -62,12 +62,12 @@ class AWSBatchExporter(abc.AbstractExporter):
 
     @staticmethod
     @requires(['boto3'], name='AWSBatchExporter')
-    def _export(cfg, env_name, mode, until, skip_tests):
+    def _export(cfg, env_name, mode, until, skip_tests, ignore_git):
         with Commander(workspace=env_name,
                        templates_path=('soopervisor', 'assets')) as cmdr:
-            tasks, args = commons.load_tasks(cmdr=cmdr,
-                                             name=env_name,
-                                             mode=mode)
+            tasks, cli_args = commons.load_tasks(cmdr=cmdr,
+                                                 name=env_name,
+                                                 mode=mode)
 
             if not tasks:
                 raise CommanderStop(f'Loaded DAG in {mode!r} mode has no '
@@ -78,12 +78,14 @@ class AWSBatchExporter(abc.AbstractExporter):
                                                  cfg,
                                                  env_name,
                                                  until=until,
-                                                 skip_tests=skip_tests)
+                                                 entry_point=cli_args[1],
+                                                 skip_tests=skip_tests,
+                                                 ignore_git=ignore_git)
 
             cmdr.info('Submitting jobs to AWS Batch')
 
             submit_dag(tasks=tasks,
-                       args=args,
+                       args=cli_args,
                        job_def=pkg_name,
                        remote_name=remote_name,
                        job_queue=cfg.job_queue,
