@@ -1,13 +1,27 @@
 import importlib
 from pathlib import Path
 
-from click import ClickException
 from ploomber.util import default
 from ploomber.io._commander import CommanderStop
-from soopervisor.commons import source
+
+from soopervisor.commons import source, dependencies
+from soopervisor.exceptions import ConfigurationError
 
 
-def build(e, cfg, name, until, skip_tests=False):
+def _validate_repository(repository):
+    if repository == 'your-repository/name':
+        raise ConfigurationError(
+            f'Invalid repository {repository!r} '
+            'in soopervisor.yaml, please add a valid value.')
+
+
+def build(e,
+          cfg,
+          name,
+          until,
+          entry_point,
+          skip_tests=False,
+          ignore_git=False):
     """Build a docker image
 
     Parameters
@@ -24,9 +38,14 @@ def build(e, cfg, name, until, skip_tests=False):
     until : str
         Stop after certain starge
 
+    entry_point : str
+        Entry point to use path/to/pipeline.yaml
+
     skip_tests : bool, default=False
         Skip image testing (check dag loading and File.client configuration)
     """
+    # raise an error if the user didn't change the default value
+    _validate_repository(cfg.repository)
 
     # if this is a pkg, get the name
     try:
@@ -40,14 +59,12 @@ def build(e, cfg, name, until, skip_tests=False):
         version = importlib.import_module(pkg_name).__version__.replace(
             '+', '-plus-')
 
+    dependencies.check_lock_files_exist()
+
     if Path('requirements.lock.txt').exists():
         e.cp('requirements.lock.txt')
     elif Path('environment.lock.yml').exists():
         e.cp('environment.lock.yml')
-    else:
-        raise ClickException('Expected environment.lock.yml or '
-                             'requirements.txt.lock at the root '
-                             'directory. Add one and try again')
 
     # generate source distribution
 
@@ -66,7 +83,8 @@ def build(e, cfg, name, until, skip_tests=False):
                     src='.',
                     dst=target,
                     include=cfg.include,
-                    exclude=cfg.exclude)
+                    exclude=cfg.exclude,
+                    ignore_git=ignore_git)
         source.compress_dir(target, Path('dist', f'{pkg_name}.tar.gz'))
 
     e.cp('dist')
@@ -90,6 +108,8 @@ def build(e, cfg, name, until, skip_tests=False):
               image_local,
               'ploomber',
               'status',
+              '--entry-point',
+              entry_point,
               description='Testing image',
               error_message='Error while testing your docker image with',
               hint=f'Use "docker run -it {image_local} /bin/bash" to '
@@ -97,7 +117,9 @@ def build(e, cfg, name, until, skip_tests=False):
 
         # check that the pipeline in the image has a configured File.client
         test_cmd = ('from ploomber.spec import DAGSpec; '
-                    'print("File" in DAGSpec.find().to_dag().clients)')
+                    f'print("File" in DAGSpec("{entry_point}")'
+                    '.to_dag().clients)')
+
         e.run('docker',
               'run',
               image_local,
@@ -115,7 +137,6 @@ def build(e, cfg, name, until, skip_tests=False):
     if until == 'build':
         raise CommanderStop('Done. Run "docker images" to see your image.')
 
-    # TODO: validate format of cfg.repository
     if cfg.repository:
         image_target = f'{cfg.repository}:{version}'
         e.run('docker',
