@@ -1,7 +1,7 @@
 import tarfile
 import os.path
 import shutil
-from pathlib import Path
+from pathlib import Path, PurePosixPath
 from itertools import chain
 from glob import iglob
 import subprocess
@@ -10,6 +10,14 @@ from click.exceptions import ClickException
 
 
 def git_tracked_files():
+    """
+    Returns
+    -------
+    list or None
+        List of tracked files or None if an error happened
+    None of str
+        None if successfully retrieved tracked files, str if an error happened
+    """
     res = subprocess.run(['git', 'ls-tree', '-r', 'HEAD', '--name-only'],
                          stdout=subprocess.PIPE,
                          stderr=subprocess.PIPE)
@@ -57,7 +65,36 @@ def glob_all(path, exclude=None):
             yield path
 
 
-def copy(cmdr, src, dst, include=None, exclude=None):
+def to_posix_str(path):
+    return str(PurePosixPath(*Path(path).parts))
+
+
+def copy(cmdr, src, dst, include=None, exclude=None, ignore_git=False):
+    """Copy files
+
+    Parameters
+    ----------
+    cmdr : Commander
+        Commander object
+
+    src : str
+        Source folder
+
+    include : list
+        List of files or directories to include (use it if you have files
+        that are not tracked by git but you want to include anyway)
+
+    exclude : list
+        List of files or directories to exclude (use it if you are tracking
+        files with git that you don't want to include)
+
+    dst : str
+        Destiny folder
+
+    ignore_git : bool, default=False
+        If False, it only copies files tracked by git, otherwise it copies
+        everything (but still applies the include/exclude rules)
+    """
     include = set() if include is None else set(include)
     exclude = set() if exclude is None else set(exclude)
     exclude_dirs = set(p for p in exclude if Path(p).is_dir())
@@ -70,7 +107,7 @@ def copy(cmdr, src, dst, include=None, exclude=None):
                              f'overlapping elements: {overlap}')
 
     if git_is_dirty():
-        cmdr.warn_on_exit('Your git repository contains untracked '
+        cmdr.warn_on_exit('Your git repository contains uncommitted '
                           'files, which will be ignored when building the '
                           'Docker image. Commit them if needed.')
 
@@ -82,8 +119,16 @@ def copy(cmdr, src, dst, include=None, exclude=None):
             'will be included, except for files in the \'exclude\' section '
             'of soopervisor.yaml')
 
+    if not tracked and not error and not ignore_git:
+        raise ClickException("Running inside a git repository, but no files "
+                             "in the current working directory are tracked "
+                             "by git. Commit the files to include them in "
+                             "the Docker image or pass the --ignore-git "
+                             "flag to soopervisor export")
+
     for f in glob_all(path=src, exclude=dst):
-        tracked_by_git = tracked is None or f in tracked
+        tracked_by_git = (tracked is None or ignore_git
+                          or to_posix_str(f) in tracked)
         excluded = f in exclude or is_relative_to_any(f, exclude_dirs)
         included = f in include or is_relative_to_any(f, include_dirs)
         # never include .git or .gitignore
