@@ -3,6 +3,7 @@ from soopervisor.aws.batch import AWSBatchExporter
 from soopervisor.aws.lambda_ import AWSLambdaExporter
 from soopervisor.airflow.export import AirflowExporter
 from soopervisor.argo.export import ArgoWorkflowsExporter
+from soopervisor.shell.export import SlurmExporter
 
 
 def for_backend(backend):
@@ -11,6 +12,7 @@ def for_backend(backend):
         Backend.aws_lambda: AWSLambdaExporter,
         Backend.airflow: AirflowExporter,
         Backend.argo_workflows: ArgoWorkflowsExporter,
+        Backend.slurm: SlurmExporter,
     }
 
     if backend not in Backend:
